%define module_name ipt_NETFLOW
%define dkms_package dkms-%{module_name}

Name:		%{module_name}
Version:	2.3
Release:	%mkrel 1
Summary:	DKMS-ready module for ipt_netflow an iptables modules
Group:		Development/Kernel
License:	GPLv3
Source:		https://github.com/aabc/ipt-netflow/releases/%{module_name}-v%{version}.tar.gz
# Disable searching for iptables sources, not used anyway
Patch0:		ipt_NETFLOW-2.3-nosrc.patch
# fix missed version change
Patch1:		ipt-netflow-2.3-fix-version.patch

BuildRequires:	pkgconfig(libiptc)
BuildRequires:	pkgconfig(xtables)
BuildRequires:	kernel-desktop-devel-latest

%description
ipt_netflow is very fast and effective Netflow exporting module for Linux kernel.
This is netfilter/iptables module adding support for NETFLOW target.

%package -n %{dkms_package}
Summary:	DKMS-ready module for ipt_netflow an iptables modules
Provides:	kmod(ipt_NETFLOW.ko) = %{version}
Requires(pre):	dkms
Requires(post):	dkms
BuildArch:	noarch

%description -n %{dkms_package}
ipt_netflow is very fast and effective Netflow exporting module for Linux kernel.
This is netfilter/iptables module adding support for NETFLOW target.

This package provides the %{module_name} kernel module(s).

%package -n iptables-NETFLOW
Summary:	The NETFLOW library which will be loaded by iptables when NETFLOW rules are processed
Requires:	kmod(ipt_NETFLOW.ko)

%description -n iptables-NETFLOW
The NETFLOW library which will be loaded by iptables when NETFLOW rules are processed.

%prep
%setup -q -n ipt-netflow-%{version}
%autopatch -p1

%build
%setup_compile_flags
# set kernel-devel dir
KPKG=$(rpm -q --requires kernel-desktop-devel-latest | grep kernel-desktop-devel)
KDIR=$(rpm -ql $KPKG | grep '/usr/src/[^/]*$')
./configure --kdir=$KDIR
%make_build libipt_NETFLOW.so LIBS=-lxtables

%install
# Install the library
make DESTDIR=%{buildroot} linstall

# generate version.h
./version.sh --define > version.h
# Install the sources of the module
mkdir -p %{buildroot}/usr/src/
mkdir -p %{buildroot}/usr/src/%{module_name}-%{version}-%{release}
cp -a  ../ipt-netflow-%{version}/*.{c,h} ../ipt-netflow-%{version}/Makefile %{buildroot}/usr/src/%{module_name}-%{version}-%{release}

cat > %{buildroot}/usr/src/%{module_name}-%{version}-%{release}/dkms.conf <<EOF

PACKAGE_VERSION="%{version}-%{release}"

#Items below here should not have to change with each driver version
PACKAGE_NAME="%{module_name}"
CLEAN="make clean"
BUILT_MODULE_NAME[0]="%{module_name}"
DEST_MODULE_LOCATION[0]="/kernel/net/netfilter/"
AUTOINSTALL=yes
EOF

%post -n %{dkms_package}
dkms add -m %{module_name} -v %{version}-%{release} --rpm_safe_upgrade
dkms build -m %{module_name} -v %{version}-%{release} --rpm_safe_upgrade
dkms install -m %{module_name} -v %{version}-%{release} --rpm_safe_upgrade

%preun -n %{dkms_package}
dkms remove -m %{module_name} -v %{version}-%{release} --rpm_safe_upgrade --all || :

%files -n %{dkms_package}
/usr/src/%{module_name}-%{version}-%{release}

%files -n iptables-NETFLOW
/%{_lib}/iptables/libipt_NETFLOW.so
/%{_lib}/iptables/libip6t_NETFLOW.so


%changelog
* Sat Sep 08 2018 tmb <tmb> 2.3-1.mga6
  (not released yet)
+ Revision: 1257750
- update to 2.3
  * rediff P0
  * drop obsolete P1-P4
- fix module version
- update filelists
- BR kernel-desktop-devel-latest

* Mon Feb 08 2016 umeabot <umeabot> 1.8-9.mga6
+ Revision: 948175
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.8-8.mga5
+ Revision: 739068
- Second Mageia 5 Mass Rebuild

* Wed Sep 24 2014 tmb <tmb> 1.8-7.mga5
+ Revision: 724118
- adapt to new kmod provides

* Tue Sep 16 2014 umeabot <umeabot> 1.8-6.mga5
+ Revision: 680548
- Mageia 5 Mass Rebuild

* Tue Feb 11 2014 pterjan <pterjan> 1.8-5.mga5
+ Revision: 589455
- Update patch for kernel 3.11

* Mon Oct 21 2013 umeabot <umeabot> 1.8-4.mga4
+ Revision: 540829
- Mageia 4 Mass Rebuild

* Thu Oct 10 2013 pterjan <pterjan> 1.8-3.mga4
+ Revision: 494358
- Copy only needed files, to avoid getting the built .so in the dkms

* Sat Oct 05 2013 pterjan <pterjan> 1.8-2.mga4
+ Revision: 492016
- Fix package name
- Fix scriptlets
- Include release in dkms version, else dkms gets upset on update
- Patch for recent kernels

* Sat Oct 05 2013 pterjan <pterjan> 1.8-1.mga4
+ Revision: 492006
- imported package ipt_NETFLOW

